@@ -270,7 +270,9 @@ def _transition(ast, scene, parent, states):
     ''' Add a transition to a scene '''
     for each in ast.actions:
         # pylint: disable=E1111
-        parent = render(each, scene=scene, parent=parent, states=states)
+        if not each.no_render:
+            # Some actions may be added by the parser, but should not appear
+            parent = render(each, scene=scene, parent=parent, states=states)
 
     if ast.terminator:
         render(ast.terminator, scene=scene, parent=parent, states=states)
@@ -307,7 +309,10 @@ def _procedure_call(ast, scene, parent, states):
 @render.register(ogAST.Decision)
 def _decision(ast, scene, parent, states):
     ''' Create a DECISION symbol and all its answers '''
-    symbol = sdlSymbols.Decision(parent, ast=ast)
+    if ast.kind == 'alternative':
+        symbol = sdlSymbols.Alternative(parent, ast=ast)
+    else:
+        symbol = sdlSymbols.Decision(parent, ast=ast)
     # Place the symbol at absolute coordinates
     if not parent:
         symbol.pos_x, symbol.pos_y = ast.pos_x, ast.pos_y
